Package: detzrcr
Authors@R: c(
    person("Magnus", "Kristoffersen", email="magnus.kristoffersen@geo.uio.no",
    role=c("aut", "cre")))
Type: Package
Title: Compare Detrital Zircon Suites
Version: 0.3.3
Description: Compare detrital zircon suites by uploading univariate,
      U-Pb age, or bivariate, U-Pb age and Lu-Hf data, in a 'shiny'-based
      user-interface. Outputs publication quality figures using 'ggplot2', and
      tables of statistics currently in use in the detrital zircon geochronology
      community.
License: GPL-3
URL: https://github.com/magnuskristoffersen/detzrcr
RoxygenNote: 7.3.3
Imports: ggplot2, shiny, MASS, stats, graphics, utils, DT, yaml
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2026-04-30 10:19:07 UTC; magnukr
Author: Magnus Kristoffersen [aut, cre]
Maintainer: Magnus Kristoffersen <magnus.kristoffersen@geo.uio.no>
Repository: CRAN
Date/Publication: 2026-05-04 06:50:02 UTC
Built: R 4.6.0; ; 2026-05-04 08:09:08 UTC; unix
