# Generated by roxygen2: do not edit by hand

export(calc_ab)
export(calc_dens)
export(calc_dens_hist)
export(calc_dkw)
export(calc_hf)
export(calc_o_param)
export(calc_p_apply)
export(calc_quantiles)
export(check_conc)
export(combine_matrices)
export(concX)
export(concY)
export(dzr_mix)
export(find_maxima)
export(find_plot_max)
export(find_plot_min)
export(find_plot_min_max)
export(hf_lines)
export(make_tiling)
export(o_param_matrix_age)
export(o_param_matrix_tdm)
export(plot_axis_lim)
export(plot_bw_theme)
export(plot_dens)
export(plot_dens_hist)
export(plot_ecdf)
export(plot_hf)
export(plot_labels)
export(plot_point_scale)
export(plot_quantiles)
export(plot_reimink)
export(plot_text_options)
export(plot_tile)
export(populate_matrix)
export(quant_bounds)
export(reimink)
export(run_detzrcr)
export(satkoski_1d)
export(satkoski_1d_matrix)
export(satkoski_2d)
export(satkoski_2d_matrix)
export(tile_func)
export(tiling)
