% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/calculations.R
\name{tile_func}
\alias{tile_func}
\title{Ready 1-O matrix for tile plot}
\usage{
tile_func(x)
}
\arguments{
\item{x}{1-O parameter vector}
}
\description{
Ready 1-O matrix for tile plot
}
