% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plotting.R
\name{plot_bw_theme}
\alias{plot_bw_theme}
\title{Stripped down theme for ggplot2}
\usage{
plot_bw_theme()
}
\value{
Returns ggplot2 theme
}
\description{
Stripped down theme for ggplot2
}
