% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/run_detzrcr.R
\name{run_detzrcr}
\alias{run_detzrcr}
\title{Launch shiny interface}
\usage{
run_detzrcr(...)
}
\arguments{
\item{...}{Pass arguments on to shiny::runApp}
}
\description{
Launch shiny interface
}
