% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/calculations.R
\name{concX}
\alias{concX}
\title{Calculate U235 at given age}
\usage{
concX(age)
}
\arguments{
\item{age}{input age}
}
\description{
Calculate U235 at given age
}
