% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/calculations.R
\name{tiling}
\alias{tiling}
\title{Apply tile_func to vector}
\usage{
tiling(z)
}
\arguments{
\item{z}{1-O parameter vector}
}
\description{
Apply tile_func to vector
}
