% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plotting.R
\name{plot_tile}
\alias{plot_tile}
\title{Tile plot of 1-O matrix}
\usage{
plot_tile(dat, type)
}
\arguments{
\item{dat}{data.frame}

\item{type}{What to plot}
}
\description{
Tile plot of 1-O matrix
}
