% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plotting.R
\name{plot_point_scale}
\alias{plot_point_scale}
\title{Add manual shape scale to scatter plot}
\usage{
plot_point_scale()
}
\description{
Add manual shape scale to scatter plot
}
